@@ -1,6 +1,6 @@
 /*
   Licensed under the GNU Public License.
-  Copyright (C) 1998-2001 by Thomas M. Vier, Jr. All Rights Reserved.
+  Copyright (C) 1998-2002 by Thomas M. Vier, Jr. All Rights Reserved.
 
   wipe is free software.
   See LICENSE for more information.
@@ -20,10 +20,10 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#define VERSION "2.0"
-#define COPYRIGHT "Copyright (C) 1998-2001 Thomas M. Vier, Jr. All Rights Reserved."
+#define VERSION "2.0.1"
+#define COPYRIGHT "Copyright (C) 1998-2002 Thomas M. Vier, Jr. All Rights Reserved."
 
-#define EMAIL "nester@users.sourceforge.net"
+#define EMAIL "nester@users.sf.net"
 
-#define URL "http://wipe.sourceforge.net/"
+#define URL "http://wipe.sf.net/"
 #define FRESHMEAT "http://freshmeat.net/projects/ya-wipe/"
